%% Hysteresis model after Dhaouadi, Ghorbel, Gandhi
% Measurement data input and processing

% Mathias Lindner
% August 2012


	%%
	function [h, b, field_up, b_max, b_min] = data_in(datapath, nr_fil, data_split, ...
		N1, N2, A_m, l_m, filter_windowsize)

		%% Import Data
		%datapath = './Messdaten/IBN120216_PCB_';

		% read emf and exitation current
		for i = 2:(nr_fil+1)
			if data_split
				% current and voltage split in two files (from LeCroy oszi)
				buf = csvread([datapath int2str(i+2) '_U2.csv'], 5, 0);
				i1(i-1,:) = csvread([datapath int2str(i+2) '_I1.csv'], 5, 1);
				% min data length
				buflen = min([length(buf), length(i1)]);
				% reduce data length and save
				i1(i-1,:) = i1(i-1,1:buflen);
				t(i-1,:) = buf(1:buflen,1);
				u2(i-1,:) = buf(1:buflen,2);
				
			else
				% current and voltage in one file (from LabVIEW)
				buf = dlmread([datapath int2str(i-1) '.csv'], ';', 1, 0);
				t(i-1,:) = buf(:,1)/1000; %in file [ms]
				i1(i-1,:) = buf(:,2);
				u2(i-1,:) = buf(:,3);
			end
		end



		%% Filter data (blockwise average)
		% window size for filter
		windowsize = filter_windowsize;

		t_fir = zeros(nr_fil, floor(length(t)/windowsize));
		u2_fir = zeros(size(t_fir));
		i1_fir = zeros(size(t_fir));
		%run through blocks
		for i=1:length(t_fir)
			t_fir(:,i) = mean(t(:, ((i-1)*windowsize+1):(i*windowsize)), 2);
			i1_fir(:,i) = mean(i1(:, ((i-1)*windowsize+1):(i*windowsize)), 2);
			u2_fir(:,i) = mean(u2(:, ((i-1)*windowsize+1):(i*windowsize)), 2);
		end


	% 	%moving average (not working, too small output)
	% 	i1_fir = filter(ones(1,windowsize)/windowsize, 1, i1);
	% 	u2_fir = filter(ones(1,windowsize)/windowsize, 1, u2);	
	% 	% remove first (windowsize-1) points due to wrong data
	% 	t_fir = t(:,windowsize-1:end);
	% 	i1_fir = i1_fir(:,windowsize-1:end);
	% 	u2_fir = u2_fir(:,windowsize-1:end);



		%% Calculate field magnitudes
		% field strength
% 		h = i1_fir * 24 / 0.613;
		h = i1_fir * N1 / l_m;
		% remove offset
		%h = h - (ones(length(h),1)*mean(h,2)')';

		%induction
		b = zeros(size(u2_fir));
		for i=1:nr_fil
% 			b(i,:) = cumtrapz(t_fir(i,:), u2_fir(i,:) - mean(u2_fir(i,:))) / ...
% 				(N2 * A_m);
			b(i,:) = cumtrapz(t_fir(i,:), u2_fir(i,:)) / ...
				(N2 * A_m);

		end
		% remove offset
		b = b - (ones(length(b),1)*mean(b,2)')';

		% detect maximum
		% replace by sine fit and parameter detection later
		b_max = max(b,[],2);
		b_min = abs(min(b,[],2));




		%% Find data with ascending induction
		field_up = false(size(h));
		for i=1:nr_fil
			field_up(i,:) = (gradient(b(i,:)) > 0);
		end
	
	
	end
	
	
	
	
	
	
	
	
	